Index: ext/background.js |
=================================================================== |
--- a/ext/background.js |
+++ b/ext/background.js |
@@ -694,21 +694,25 @@ |
}, |
onChanged: chrome.storage.onChanged |
}; |
/* Options */ |
ext.showOptions = callback => |
{ |
+ let info = require("info"); |
+ |
if ("openOptionsPage" in chrome.runtime && |
// Firefox for Android does have a runtime.openOptionsPage but it |
// doesn't do anything. |
// https://bugzilla.mozilla.org/show_bug.cgi?id=1364945 |
- require("info").application != "fennec") |
+ (info.application != "fennec" || |
+ (parseInt(info.applicationVersion, 10) >= 57 && |
+ info.applicationVersion != "57.0a1"))) |
Manish Jethani
2017/08/25 09:20:53
This extra check here is specifically for the curr
@@ -694,21 +694,25 @@ |
if ("openOptionsPage" in chrome.runtime && |
- // Firefox for Android does have a runtime.openOptionsPage but it |
- // doesn't do anything. |
+ // Some versions of Firefox for Android before version 57 do have a |
+ // runtime.openOptionsPage but it doesn't do anything. |
// https://bugzilla.mozilla.org/show_bug.cgi?id=1364945 |
|
{ |
if (!callback) |
{ |
chrome.runtime.openOptionsPage(); |
} |
else |
{ |
chrome.runtime.openOptionsPage(() => |